@@ -19,24 +19,24 @@ def CaptureJob():
     issues = list(
         filter(
             checkPrerequsites,
-            ["CAPTURE_CONNECTION_STRING","CAPTURE_CONTAINER_NAME","TASK_ID"],
+            ["CAPTURE_CONNECTION_STRING","CAPTURE_CONTAINER_NAME","TASK_ID","JOB_DATE"],
         )
     )
     if len(issues) > 0:
         raise Exception(f"Missing environment variables {issues}")
 
-    config = DotMap({
+    config = DotMap({        
         "connectionString": os.environ.get("CAPTURE_CONNECTION_STRING"),
         "containerName": os.environ.get("CAPTURE_CONTAINER_NAME"),
     })
 
-    print(config.containerName)
+    # print(config.containerName)
     fileservice =FileService(config)
 
     job = os.environ.get("TASK_ID")
 
     now = datetime.now() 
-    date_time = now.strftime("%Y%m%d_%H%M%S")    
+    date_time = os.environ.get("JOB_DATE") or now.strftime("%Y%m%d_%H%M%S")    
 
     cwd = os.getcwd()
     
